@@ -2092,7 +2092,7 @@ xfpm_settings_dialog_new (XfconfChannel *channel, gboolean auth_suspend,
     {
     frame = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-frame"));
     gtk_widget_hide (frame);
-    frame = GTK_WIDGET (gtk_builder_get_object (xml, "keys-frame"));
+    frame = GTK_WIDGET (gtk_builder_get_object (xml, "handle-brightness-keys"));
     gtk_widget_hide (frame);
     }
 
