@@ -36,6 +36,7 @@
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
 #include <upower.h>
+#include <gdk/gdkx.h>
 
 #include <libxfce4util/libxfce4util.h>
 #include <libxfce4ui/libxfce4ui.h>
@@ -60,6 +61,7 @@
 #include "egg-idletime.h"
 #include "xfpm-systemd.h"
 #include "xfpm-suspend.h"
+#include "xfpm-brightness.h"
 
 
 static void xfpm_power_finalize     (GObject *object);
@@ -77,10 +79,11 @@ static void xfpm_power_set_property (GObject *object,
 static void xfpm_power_change_presentation_mode (XfpmPower *power,
 						 gboolean presentation_mode);
 
+static void xfpm_update_blank_time (XfpmPower *power);
+
 static void xfpm_power_dbus_class_init (XfpmPowerClass * klass);
 static void xfpm_power_dbus_init (XfpmPower *power);
 
-static gboolean xfpm_power_prompt_password (XfpmPower *power);
 
 #define XFPM_POWER_GET_PRIVATE(o) \
 (G_TYPE_INSTANCE_GET_PRIVATE ((o), XFPM_TYPE_POWER, XfpmPowerPrivate))
@@ -102,10 +105,10 @@ struct XfpmPowerPrivate
     XfpmBatteryCharge overall_state;
     gboolean         critical_action_done;
 
-#ifdef HAVE_DPMS
     XfpmDpms        *dpms;
-#endif
     gboolean         presentation_mode;
+    gint             on_ac_blank;
+    gint             on_battery_blank;
     EggIdletime     *idletime;
 
     gboolean	     inhibited;
@@ -117,8 +120,6 @@ struct XfpmPowerPrivate
     gboolean	     auth_suspend;
     gboolean	     auth_hibernate;
 
-    XfpmSuspend     *suspend;
-
     /* Properties */
     gboolean	     on_low_battery;
     gboolean	     lid_is_present;
@@ -146,6 +147,8 @@ enum
     PROP_CAN_HIBERNATE,
     PROP_HAS_LID,
     PROP_PRESENTATION_MODE,
+    PROP_ON_AC_BLANK,
+    PROP_ON_BATTERY_BLANK,
     N_PROPERTIES
 };
 
@@ -178,8 +181,13 @@ xfpm_power_check_polkit_auth (XfpmPower *power)
     }
     else
     {
+#if !UP_CHECK_VERSION(0, 99, 0)
 	suspend   = POLKIT_AUTH_SUSPEND_UPOWER;
 	hibernate = POLKIT_AUTH_HIBERNATE_UPOWER;
+#else
+	suspend   = POLKIT_AUTH_SUSPEND_XFPM;
+	hibernate = POLKIT_AUTH_HIBERNATE_XFPM;
+#endif
     }
     power->priv->auth_suspend = xfpm_polkit_check_auth (power->priv->polkit,
 							suspend);
@@ -197,9 +205,9 @@ xfpm_power_check_power (XfpmPower *power, gboolean on_battery)
 	    GList *list;
 	    guint len, i;
 	    g_signal_emit (G_OBJECT (power), signals [ON_BATTERY_CHANGED], 0, on_battery);
-#ifdef HAVE_DPMS
+
         xfpm_dpms_set_on_battery (power->priv->dpms, on_battery);
-#endif
+
 	    power->priv->on_battery = on_battery;
 	    list = g_hash_table_get_values (power->priv->hash);
 	    len = g_list_length (list);
@@ -208,6 +216,7 @@ xfpm_power_check_power (XfpmPower *power, gboolean on_battery)
 		g_object_set (G_OBJECT (g_list_nth_data (list, i)),
 			      "ac-online", !on_battery,
 			      NULL);
+        xfpm_update_blank_time (power);
 	    }
 	}
 }
@@ -312,6 +321,8 @@ xfpm_power_sleep (XfpmPower *power, const gchar *sleep_time, gboolean force)
 #ifdef WITH_NETWORK_MANAGER
     gboolean network_manager_sleep;
 #endif
+    XfpmBrightness *brightness;
+    gint32 brightness_level;
 
     if ( power->priv->inhibited && force == FALSE)
     {
@@ -327,23 +338,11 @@ xfpm_power_sleep (XfpmPower *power, const gchar *sleep_time, gboolean force)
 	    return;
     }
 
-/* Upower dropped support for doing anything power related */
-#if UP_CHECK_VERSION(0, 99, 0)
-    if ( !LOGIND_RUNNING () )
-    {
-	/* See if we require a password for sudo to call suspend */
-	if ( xfpm_suspend_password_required (power->priv->suspend) )
-	{
-	    if ( !xfpm_power_prompt_password (power) )
-	    {
-		xfpm_power_report_error (power, _("Incorrect password entered"), "dialog-error");
-		return;
-	    }
-	}
-    }
-#endif
-
     g_signal_emit (G_OBJECT (power), signals [SLEEPING], 0);
+    /* Get the current brightness level so we can use it after we suspend */
+    brightness = xfpm_brightness_new();
+    xfpm_brightness_setup (brightness);
+    xfpm_brightness_get_level (brightness, &brightness_level);
 
 #ifdef WITH_NETWORK_MANAGER
     g_object_get (G_OBJECT (power->priv->conf),
@@ -404,13 +403,11 @@ xfpm_power_sleep (XfpmPower *power, const gchar *sleep_time, gboolean force)
 #else
 	if (!g_strcmp0 (sleep_time, "Hibernate"))
         {
-            if (xfpm_suspend_sudo_get_state (power->priv->suspend) == SUDO_AVAILABLE)
-                xfpm_suspend_sudo_try_action (power->priv->suspend, XFPM_HIBERNATE, &error);
+                xfpm_suspend_try_action (XFPM_HIBERNATE);
         }
         else
         {
-            if (xfpm_suspend_sudo_get_state (power->priv->suspend) == SUDO_AVAILABLE)
-                xfpm_suspend_sudo_try_action (power->priv->suspend, XFPM_SUSPEND, &error);
+                xfpm_suspend_try_action (XFPM_SUSPEND);
         }
 #endif
     }
@@ -429,6 +426,11 @@ xfpm_power_sleep (XfpmPower *power, const gchar *sleep_time, gboolean force)
     }
 
     g_signal_emit (G_OBJECT (power), signals [WAKING_UP], 0);
+    /* Check/update any changes while we slept */
+    xfpm_power_get_properties (power);
+    /* Restore the brightness level from before we suspended */
+    xfpm_brightness_set_level (brightness, brightness_level);
+
 #ifdef WITH_NETWORK_MANAGER
     if ( network_manager_sleep )
     {
@@ -1061,6 +1063,24 @@ xfpm_power_class_init (XfpmPowerClass *klass)
                                                           NULL, NULL,
                                                           FALSE,
                                                           XFPM_PARAM_FLAGS));
+
+    g_object_class_install_property (object_class,
+                                     PROP_ON_AC_BLANK,
+                                     g_param_spec_int  (ON_AC_BLANK,
+                                                        NULL, NULL,
+                                                        0,
+                                                        G_MAXINT16,
+                                                        10,
+                                                        XFPM_PARAM_FLAGS));
+
+    g_object_class_install_property (object_class,
+                                     PROP_ON_BATTERY_BLANK,
+                                     g_param_spec_int  (ON_BATTERY_BLANK,
+                                                        NULL, NULL,
+                                                        0,
+                                                        G_MAXINT16,
+                                                        10,
+                                                        XFPM_PARAM_FLAGS));
 #undef XFPM_PARAM_FLAGS
 
     g_type_class_add_private (klass, sizeof (XfpmPowerPrivate));
@@ -1088,11 +1108,12 @@ xfpm_power_init (XfpmPower *power)
     power->priv->dialog          = NULL;
     power->priv->overall_state   = XFPM_BATTERY_CHARGE_OK;
     power->priv->critical_action_done = FALSE;
-#ifdef HAVE_DPMS
+
     power->priv->dpms                 = xfpm_dpms_new ();
-#endif
+
     power->priv->presentation_mode    = FALSE;
-    power->priv->suspend = xfpm_suspend_get ();
+    power->priv->on_ac_blank          = 15;
+    power->priv->on_battery_blank     = 10;
 
     power->priv->inhibit = xfpm_inhibit_new ();
     power->priv->notify  = xfpm_notify_new ();
@@ -1137,10 +1158,6 @@ xfpm_power_init (XfpmPower *power)
     xfpm_power_check_polkit_auth (power);
 #endif
 
-    xfconf_g_property_bind(xfpm_xfconf_get_channel(power->priv->conf),
-			   PROPERTIES_PREFIX PRESENTATION_MODE, G_TYPE_BOOLEAN,
-                           G_OBJECT(power), PRESENTATION_MODE);
-
 out:
     xfpm_power_dbus_init (power);
 
@@ -1181,6 +1198,12 @@ static void xfpm_power_get_property (GObject *object,
 	case PROP_PRESENTATION_MODE:
 	    g_value_set_boolean (value, power->priv->presentation_mode);
 	    break;
+    case PROP_ON_AC_BLANK:
+      g_value_set_int (value, power->priv->on_ac_blank);
+      break;
+    case PROP_ON_BATTERY_BLANK:
+      g_value_set_int (value, power->priv->on_battery_blank);
+      break;
         default:
             G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
             break;
@@ -1193,12 +1216,23 @@ static void xfpm_power_set_property (GObject *object,
 				     GParamSpec *pspec)
 {
     XfpmPower *power = XFPM_POWER (object);
+    gint on_ac_blank, on_battery_blank;
 
     switch (prop_id)
     {
 	case PROP_PRESENTATION_MODE:
 	    xfpm_power_change_presentation_mode (power, g_value_get_boolean (value));
 	    break;
+    case PROP_ON_AC_BLANK:
+          on_ac_blank = g_value_get_int (value);
+          power->priv->on_ac_blank = on_ac_blank;
+          xfpm_update_blank_time (power);
+          break;
+      case PROP_ON_BATTERY_BLANK:
+          on_battery_blank = g_value_get_int (value);
+          power->priv->on_battery_blank = on_battery_blank;
+          xfpm_update_blank_time (power);
+          break;
         default:
             G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
             break;
@@ -1231,13 +1265,31 @@ xfpm_power_finalize (GObject *object)
     g_object_unref (power->priv->polkit);
 #endif
 
-#ifdef HAVE_DPMS
     g_object_unref(power->priv->dpms);
-#endif
 
     G_OBJECT_CLASS (xfpm_power_parent_class)->finalize (object);
 }
 
+static XfpmPower*
+xfpm_power_new (void)
+{
+    XfpmPower *power = XFPM_POWER(g_object_new (XFPM_TYPE_POWER, NULL));
+
+    xfconf_g_property_bind (xfpm_xfconf_get_channel(power->priv->conf),
+                            PROPERTIES_PREFIX PRESENTATION_MODE, G_TYPE_BOOLEAN,
+                            G_OBJECT(power), PRESENTATION_MODE);
+
+    xfconf_g_property_bind (xfpm_xfconf_get_channel(power->priv->conf),
+                            PROPERTIES_PREFIX ON_BATTERY_BLANK, G_TYPE_INT,
+                            G_OBJECT (power), ON_BATTERY_BLANK);
+
+    xfconf_g_property_bind (xfpm_xfconf_get_channel(power->priv->conf),
+                            PROPERTIES_PREFIX ON_AC_BLANK, G_TYPE_INT,
+                            G_OBJECT (power), ON_AC_BLANK);
+
+    return power;
+}
+
 XfpmPower *
 xfpm_power_get (void)
 {
@@ -1245,12 +1297,12 @@ xfpm_power_get (void)
 
     if ( G_LIKELY (xfpm_power_object != NULL ) )
     {
-	g_object_ref (xfpm_power_object);
+        g_object_ref (xfpm_power_object);
     }
     else
     {
-	xfpm_power_object = g_object_new (XFPM_TYPE_POWER, NULL);
-	g_object_add_weak_pointer (xfpm_power_object, &xfpm_power_object);
+        xfpm_power_object = xfpm_power_new ();
+        g_object_add_weak_pointer (xfpm_power_object, &xfpm_power_object);
     }
 
     return XFPM_POWER (xfpm_power_object);
@@ -1293,10 +1345,29 @@ gboolean xfpm_power_has_battery (XfpmPower *power)
     return ret;
 }
 
+static void
+xfpm_update_blank_time (XfpmPower *power)
+{
+    Display* display = gdk_x11_display_get_xdisplay(gdk_display_get_default ());
+    guint screensaver_timeout;
+
+    if (power->priv->on_battery)
+        screensaver_timeout = power->priv->on_battery_blank;
+    else
+        screensaver_timeout = power->priv->on_ac_blank;
+
+    /* Presentation mode disables blanking */
+    if (power->priv->presentation_mode)
+        screensaver_timeout = 0;
+
+    XFPM_DEBUG ("Timeout: %d", screensaver_timeout);
+
+    XSetScreenSaver(display, screensaver_timeout * 60, 0, DefaultBlanking, DefaultExposures);
+}
+
 static void
 xfpm_power_change_presentation_mode (XfpmPower *power, gboolean presentation_mode)
 {
-#ifdef HAVE_DPMS
     /* no change, exit */
     if (power->priv->presentation_mode == presentation_mode)
         return;
@@ -1318,7 +1389,8 @@ xfpm_power_change_presentation_mode (XfpmPower *power, gboolean presentation_mod
 
         g_object_unref (idletime);
     }
-#endif
+
+    xfpm_update_blank_time (power);
 }
 
 gboolean
@@ -1330,64 +1402,6 @@ xfpm_power_is_in_presentation_mode (XfpmPower *power)
 }
 
 
-static gboolean
-xfpm_power_prompt_password (XfpmPower *power)
-{
-    GtkWidget *dialog = gtk_message_dialog_new (NULL,
-					        GTK_DIALOG_MODAL,
-						GTK_MESSAGE_OTHER,
-						GTK_BUTTONS_OK_CANCEL,
-						_("The requested operation requires elevated privileges.\t\n"
-						"Please enter your password."));
-    GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG(dialog));
-    GtkWidget *password_entry = gtk_entry_new ();
-    GtkWidget *password_label, *hbox;
-    gint result;
-    XfpmPassState state = PASSWORD_FAILED;
-
-    /* Set the dialog's title */
-    gtk_window_set_title (GTK_WINDOW(dialog), _("xfce4-power-manager"));
-
-    /* setup password label */
-    password_label = gtk_label_new (_("Password:"));
-
-    /* Setup the password entry */
-    gtk_entry_set_visibility (GTK_ENTRY (password_entry), FALSE);
-    gtk_entry_set_max_length (GTK_ENTRY (password_entry), 1024);
-    gtk_entry_set_activates_default (GTK_ENTRY (password_entry), TRUE);
-
-    /* pack the password label and entry into an hbox */
-    hbox = gtk_hbox_new (FALSE, 4);
-    gtk_box_pack_start (GTK_BOX (hbox), password_label, FALSE, FALSE, 4);
-    gtk_box_pack_end   (GTK_BOX (hbox), password_entry, TRUE, TRUE, 4);
-
-    /* Add it to the dialog */
-    gtk_box_pack_end (GTK_BOX (content_area), hbox, TRUE, TRUE, 8);
-
-    /* show it */
-    gtk_widget_show (password_entry);
-    gtk_widget_show (password_label);
-    gtk_widget_show (hbox);
-
-    /* make enter default to ok */
-    gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
-
-    /* Run the password prompt */
-    result = gtk_dialog_run (GTK_DIALOG(dialog));
-
-    if (result == GTK_RESPONSE_OK)
-    {
-	state = xfpm_suspend_sudo_send_password (power->priv->suspend, gtk_entry_get_text (GTK_ENTRY (password_entry)));
-	XFPM_DEBUG ("password state: %s", state == PASSWORD_FAILED ? "PASSWORD_FAILED" : "PASSWORD_SUCCEED");
-    }
-
-    gtk_widget_destroy (dialog);
-
-    return state == PASSWORD_FAILED ? FALSE : TRUE;
-}
-
-
-
 /*
  *
  * DBus server implementation for org.freedesktop.PowerManagement
@@ -1421,10 +1435,6 @@ static gboolean xfpm_power_dbus_can_suspend (XfpmPower * power,
 					   gboolean * OUT_can_suspend,
 					   GError ** error);
 
-static gboolean xfpm_power_dbus_get_power_save_status (XfpmPower * power,
-						     gboolean * OUT_save_power,
-						     GError ** error);
-
 static gboolean xfpm_power_dbus_get_on_battery (XfpmPower * power,
 					      gboolean * OUT_on_battery,
 					      GError ** error);
@@ -1626,14 +1636,6 @@ static gboolean xfpm_power_dbus_can_suspend (XfpmPower * power,
     return TRUE;
 }
 
-static gboolean xfpm_power_dbus_get_power_save_status (XfpmPower * power,
-						     gboolean * OUT_save_power,
-						     GError ** error)
-{
-    //FIXME
-    return TRUE;
-}
-
 static gboolean xfpm_power_dbus_get_on_battery (XfpmPower * power,
 					      gboolean * OUT_on_battery,
 					      GError ** error)
